@@ -49,15 +49,11 @@ async def opendal_write():
         region=SETTINGS.aws_region,
         endpoint=SETTINGS.aws_endpoint,
     )
-    tasks = []
-    for case in TEST_CASE:
-        tasks.append(
-            op.write(
-                f"/benchmark/opendal_write/{case['name']}",
-                case["data"],
-            )
-        )
-    await asyncio.gather(*tasks)
+    tasks = [
+        op.write(f"/benchmark/opendal_write/{case['name']}", case["data"])
+        for case in TEST_CASE
+    ]
+    _ = await asyncio.gather(*tasks)
 
 
 async def opendal_read():
@@ -67,10 +63,8 @@ async def opendal_read():
         region=SETTINGS.aws_region,
         endpoint=SETTINGS.aws_endpoint,
     )
-    tasks = []
-    for case in TEST_CASE:
-        tasks.append(op.read(f"/benchmark/opendal_write/{case['name']}"))
-    await asyncio.gather(*tasks)
+    tasks = [op.read(f"/benchmark/opendal_write/{case['name']}") for case in TEST_CASE]
+    _ = await asyncio.gather(*tasks)
 
 
 def read_run():
