@@ -20,8 +20,6 @@ use opendal::{self as ocore, raw::BytesRange};
 use pyo3::pyclass;
 use std::collections::HashMap;
 
-use chrono::{DateTime, Utc};
-
 #[pyclass(module = "opendal")]
 #[derive(FromPyObject, Default)]
 pub struct ReadOptions {
@@ -34,8 +32,8 @@ pub struct ReadOptions {
     pub size: Option<usize>,
     pub if_match: Option<String>,
     pub if_none_match: Option<String>,
-    pub if_modified_since: Option<DateTime<Utc>>,
-    pub if_unmodified_since: Option<DateTime<Utc>>,
+    pub if_modified_since: Option<jiff::Timestamp>,
+    pub if_unmodified_since: Option<jiff::Timestamp>,
     pub content_type: Option<String>,
     pub cache_control: Option<String>,
     pub content_disposition: Option<String>,
@@ -73,8 +71,8 @@ impl From<ReadOptions> for ocore::options::ReadOptions {
             version: opts.version,
             if_match: opts.if_match,
             if_none_match: opts.if_none_match,
-            if_modified_since: opts.if_modified_since,
-            if_unmodified_since: opts.if_unmodified_since,
+            if_modified_since: opts.if_modified_since.map(Into::into),
+            if_unmodified_since: opts.if_unmodified_since.map(Into::into),
             concurrent: opts.concurrent.unwrap_or_default(),
             chunk: opts.chunk,
             gap: opts.gap,
@@ -91,8 +89,8 @@ impl From<ReadOptions> for ocore::options::ReaderOptions {
             version: opts.version,
             if_match: opts.if_match,
             if_none_match: opts.if_none_match,
-            if_modified_since: opts.if_modified_since,
-            if_unmodified_since: opts.if_unmodified_since,
+            if_modified_since: opts.if_modified_since.map(Into::into),
+            if_unmodified_since: opts.if_unmodified_since.map(Into::into),
             concurrent: opts.concurrent.unwrap_or_default(),
             chunk: opts.chunk,
             gap: opts.gap,
@@ -147,8 +145,8 @@ pub struct StatOptions {
     pub version: Option<String>,
     pub if_match: Option<String>,
     pub if_none_match: Option<String>,
-    pub if_modified_since: Option<DateTime<Utc>>,
-    pub if_unmodified_since: Option<DateTime<Utc>>,
+    pub if_modified_since: Option<jiff::Timestamp>,
+    pub if_unmodified_since: Option<jiff::Timestamp>,
     pub content_type: Option<String>,
     pub cache_control: Option<String>,
     pub content_disposition: Option<String>,
@@ -160,8 +158,8 @@ impl From<StatOptions> for ocore::options::StatOptions {
             version: opts.version,
             if_match: opts.if_match,
             if_none_match: opts.if_none_match,
-            if_modified_since: opts.if_modified_since,
-            if_unmodified_since: opts.if_unmodified_since,
+            if_modified_since: opts.if_modified_since.map(Into::into),
+            if_unmodified_since: opts.if_unmodified_since.map(Into::into),
             override_content_type: opts.content_type,
             override_cache_control: opts.cache_control,
             override_content_disposition: opts.content_disposition,
