@@ -17,9 +17,9 @@
 
 use std::os::raw::c_int;
 
+use pyo3::IntoPyObjectExt;
 use pyo3::ffi;
 use pyo3::prelude::*;
-use pyo3::IntoPyObjectExt;
 
 /// A bytes-like object that implements buffer protocol.
 #[pyclass(module = "opendal")]
@@ -36,7 +36,7 @@ impl Buffer {
     pub fn into_bytes(self, py: Python) -> PyResult<Py<PyAny>> {
         let buffer = self.into_py_any(py)?;
 
-        unsafe { PyObject::from_owned_ptr_or_err(py, ffi::PyBytes_FromObject(buffer.as_ptr())) }
+        unsafe { Py::<PyAny>::from_owned_ptr_or_err(py, ffi::PyBytes_FromObject(buffer.as_ptr())) }
     }
 
     /// Consume self to build a bytes
@@ -57,17 +57,61 @@ impl Buffer {
         flags: c_int,
     ) -> PyResult<()> {
         let bytes = slf.inner.as_slice();
-        let ret = ffi::PyBuffer_FillInfo(
-            view,
-            slf.as_ptr() as *mut _,
-            bytes.as_ptr() as *mut _,
-            bytes.len().try_into().unwrap(),
-            1, // read only
-            flags,
-        );
+        let ret = unsafe {
+            ffi::PyBuffer_FillInfo(
+                view,
+                slf.as_ptr() as *mut _,
+                bytes.as_ptr() as *mut _,
+                bytes.len().try_into().unwrap(),
+                1, // read only
+                flags,
+            )
+        };
         if ret == -1 {
             return Err(PyErr::fetch(slf.py()));
         }
         Ok(())
     }
 }
+
+/// Macro to create and register a PyO3 submodule with multiple classes.
+///
+/// Example:
+/// ```rust
+/// add_pymodule!(py, m, "services", [PyScheme, PyOtherClass]);
+/// ```
+#[macro_export]
+macro_rules! add_pymodule {
+    ($py:expr, $parent:expr, $name:expr, [$($cls:ty),* $(,)?]) => {{
+        let sub_module = pyo3::types::PyModule::new($py, $name)?;
+        $(
+            sub_module.add_class::<$cls>()?;
+        )*
+        $parent.add_submodule(&sub_module)?;
+        $py.import("sys")?
+            .getattr("modules")?
+            .set_item(format!("opendal.{}", $name), &sub_module)?;
+        Ok::<_, pyo3::PyErr>(())
+    }};
+}
+
+/// Macro to create and register a PyO3 submodule containing exception types.
+///
+/// Example:
+/// ```rust
+/// add_pyexceptions!(py, m, "exceptions", [Error, Unexpected]);
+/// ```
+#[macro_export]
+macro_rules! add_pyexceptions {
+    ($py:expr, $parent:expr, $name:expr, [$($exc:ty),* $(,)?]) => {{
+        let sub_module = pyo3::types::PyModule::new($py, $name)?;
+        $(
+            sub_module.add(stringify!($exc), $py.get_type::<$exc>())?;
+        )*
+        $parent.add_submodule(&sub_module)?;
+        $py.import("sys")?
+            .getattr("modules")?
+            .set_item(format!("opendal.{}", $name), &sub_module)?;
+        Ok::<_, pyo3::PyErr>(())
+    }};
+}
