@@ -26,10 +26,7 @@ import pytest
 @pytest.mark.asyncio
 @pytest.mark.need_capability("read", "write", "delete", "shared")
 async def test_operator_pickle(service_name, operator, async_operator):
-    """
-    Test AsyncOperator's pickle serialization and deserialization.
-    """
-
+    """Test AsyncOperator's pickle serialization and deserialization."""
     size = randint(1, 1024)
     filename = f"random_file_{str(uuid4())}"
     content = os.urandom(size)
