@@ -31,10 +31,9 @@ def test_sync_list_with_start_after(service_name, operator, async_operator):
         operator.write(f, b"test_content")
 
     # 2. Test basic list
-    entries = []
-    for entry in operator.list(test_dir):
-        entries.append(entry.path)
-    entries.sort()  # Ensure order for comparison
+    entries = sorted(
+        [entry.path for entry in operator.list(test_dir)]
+    )  # Ensure order for comparison
     expected_files = sorted([test_dir, *files_to_create])
     assert entries == expected_files, (
         f"Basic list failed. Expected {expected_files}, got {entries}"
@@ -44,9 +43,9 @@ def test_sync_list_with_start_after(service_name, operator, async_operator):
     start_after_file = files_to_create[2]  # e.g., test_dir/file_2
     entries_after = []
     # Note: start_after expects the *full path* relative to the operator root
-    for entry in operator.list(test_dir, start_after=start_after_file):
-        entries_after.append(entry.path)
-    entries_after.sort()  # Ensure order
+    entries_after = sorted(
+        [entry.path for entry in operator.list(test_dir, start_after=start_after_file)]
+    )  # Ensure order
 
     # Expected files are those lexicographically after start_after_file
     expected_files_after = sorted([f for f in files_to_create if f > start_after_file])
